@@ -6,15 +6,17 @@ This module contains the writing functionality of ``sdds``.
 It provides a high-level function to write SDDS files in different formats, and a series of helpers.
 """
 import pathlib
-from typing import IO, List, Union, Iterable
+import struct
+from typing import IO, List, Union, Iterable, Tuple, Any
 import numpy as np
 from sdds.classes import (SddsFile, Column, Parameter, Definition, Array, Data, Description,
-                          ENCODING, NUMTYPES)
+                          ENCODING, get_dtype_str)
 
 
 def write_sdds(sdds_file: SddsFile, output_path: Union[pathlib.Path, str]) -> None:
     """
     Writes SddsFile object into ``output_path``.
+    The byteorder will be big-endian, independent of the byteorder of the current machine.
 
     Args:
         sdds_file: `SddsFile` object to write
@@ -51,7 +53,7 @@ def _sdds_def_as_str(definition: Union[Description, Definition, Data]) -> str:
 
 def _write_data(names: List[str], sdds_file: SddsFile, outbytes: IO[bytes])-> None:
     # row_count:
-    outbytes.write(np.array(0, dtype=NUMTYPES["long"]).tobytes())
+    outbytes.write(np.array(0, dtype=get_dtype_str("long")).tobytes())
     _write_parameters((sdds_file[name] for name in names
                        if isinstance(sdds_file.definitions[name], Parameter)),
                       outbytes)
@@ -63,15 +65,15 @@ def _write_data(names: List[str], sdds_file: SddsFile, outbytes: IO[bytes])-> No
                    outbytes)
 
 
-def _write_parameters(param_gen: Iterable[Parameter], outbytes: IO[bytes]):
+def _write_parameters(param_gen: Iterable[Tuple[Parameter, Any]], outbytes: IO[bytes]):
     for param_def, value in param_gen:
         if param_def.type == "string":
             _write_string(value, outbytes)
         else:
-            outbytes.write(np.array(value, dtype=NUMTYPES[param_def.type]).tobytes())
+            outbytes.write(np.array(value, dtype=get_dtype_str(param_def.type)).tobytes())
 
 
-def _write_arrays(array_gen: Iterable[Array], outbytes: IO[bytes]):
+def _write_arrays(array_gen: Iterable[Tuple[Array, Any]], outbytes: IO[bytes]):
     def get_dimensions_from_array(value):
         # Return the number of items per dimension
         # For an array a[n][m], returns [n, m]
@@ -82,21 +84,21 @@ def _write_arrays(array_gen: Iterable[Array], outbytes: IO[bytes]):
     for array_def, value in array_gen:
         # Number of items per dimensions need to be written before the data
         elements_per_dim = get_dimensions_from_array(value)
-        long_array = np.array(elements_per_dim, dtype=NUMTYPES["long"])
+        long_array = np.array(elements_per_dim, dtype=get_dtype_str("long"))
         outbytes.write(long_array.tobytes())
 
         if array_def.type == "string":
             for string in value:
                 _write_string(string, outbytes)
         else:
-            outbytes.write(np.array(value, dtype=NUMTYPES[array_def.type]).tobytes())
+            outbytes.write(np.array(value, dtype=get_dtype_str(array_def.type)).tobytes())
 
 
-def _write_columns(col_gen: Iterable[Column], outbytes: IO[bytes]):
+def _write_columns(col_gen: Iterable[Tuple[Column, Any]], outbytes: IO[bytes]):
     # TODO: Implement the columns thing.
     pass
 
 
 def _write_string(string: str, outbytes: IO[bytes]):
-    outbytes.write(np.array(len(string), dtype=NUMTYPES["long"]).tobytes())
-    outbytes.write(string.encode(ENCODING))
+    outbytes.write(np.array(len(string), dtype=get_dtype_str("long")).tobytes())
+    outbytes.write(struct.pack(get_dtype_str("string", length=len(string)), string.encode(ENCODING)))
